Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions.

Bu işleme şunda yer alıyor:
Alex Voicu
2017-11-29 21:01:28 +00:00
ebeveyn 93e595c267
işleme 4792475d01
63 değiştirilmiş dosya ile 173 ekleme ve 171 silme
+1 -1
Dosyayı Görüntüle
@@ -217,7 +217,7 @@ int computeGold(int *gpuData, const int len)
__global__ void testKernel(hipLaunchParm lp,int *g_odata)
{
// access thread id
const unsigned int tid = blockDim.x * blockIdx.x + threadIdx.x;
const unsigned int tid = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
// Test various atomic instructions